@@ -21,8 +21,8 @@
 #include "PtyTest.h"
 
 // Qt
-#include <QtCore/QSize>
-#include <QtCore/QStringList>
+#include <QSize>
+#include <QStringList>
 
 // KDE
 #include <qtest.h>
